<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
<context>
    <name>dcc::keyboard::Language</name>
    <message>
        <location filename="language.h" line="31"/>
        <source>Afar</source>
        <translation>Afar</translation>
    </message>
    <message>
        <location filename="language.h" line="32"/>
        <source>Afrikaans</source>
        <translation>Africano</translation>
    </message>
    <message>
        <location filename="language.h" line="33"/>
        <source>አማርኛ</source>
        <translation>Amárico</translation>
    </message>
    <message>
        <location filename="language.h" line="34"/>
        <source>عربية</source>
        <translation>Arábe</translation>
    </message>
    <message>
        <location filename="language.h" line="35"/>
        <source>অসমীয়া</source>
        <translation>Asamés</translation>
    </message>
    <message>
        <location filename="language.h" line="36"/>
        <source>Asturianu</source>
        <translation>Asturiano</translation>
    </message>
    <message>
        <location filename="language.h" line="37"/>
        <source>Беларуская</source>
        <translation>Bielorruso</translation>
    </message>
    <message>
        <location filename="language.h" line="38"/>
        <source>Biełaruskaja łacinka</source>
        <translation>Latín Bielorruso</translation>
    </message>
    <message>
        <location filename="language.h" line="39"/>
        <source>Български</source>
        <translation>Búlgaro</translation>
    </message>
    <message>
        <location filename="language.h" line="40"/>
        <source>বাংলা</source>
        <translation>Bengalí</translation>
    </message>
    <message>
        <location filename="language.h" line="41"/>
        <source>বাংলা (ভারত)</source>
        <translation>Bengalí (India)</translation>
    </message>
    <message>
        <location filename="language.h" line="42"/>
        <source>བོད་སྐད།</source>
        <translation>Tibetano</translation>
    </message>
    <message>
        <location filename="language.h" line="43"/>
        <source>Brezhoneg</source>
        <translation>Bretón</translation>
    </message>
    <message>
        <location filename="language.h" line="44"/>
        <source>Bosanski</source>
        <translation>Bosnio</translation>
    </message>
    <message>
        <location filename="language.h" line="45"/>
        <source>Català</source>
        <translation>Catalán</translation>
    </message>
    <message>
        <location filename="language.h" line="46"/>
        <source>Qırımtatarca</source>
        <translation>Tártaro</translation>
    </message>
    <message>
        <location filename="language.h" line="47"/>
        <source>Český</source>
        <translation>Checo</translation>
    </message>
    <message>
        <location filename="language.h" line="48"/>
        <source>Kaszëbsczi</source>
        <translation>Casubio</translation>
    </message>
    <message>
        <location filename="language.h" line="49"/>
        <source>Чăвашла</source>
        <translation>Chuvasio</translation>
    </message>
    <message>
        <location filename="language.h" line="50"/>
        <source>Cymraeg</source>
        <translation>Galés</translation>
    </message>
    <message>
        <location filename="language.h" line="51"/>
        <source>Dansk</source>
        <translation>Danés</translation>
    </message>
    <message>
        <location filename="language.h" line="52"/>
        <source>Deutsch</source>
        <translation>Alemán</translation>
    </message>
    <message>
        <location filename="language.h" line="53"/>
        <source>ཇོང་ཁ</source>
        <translation>Butanés</translation>
    </message>
    <message>
        <location filename="language.h" line="54"/>
        <source>Ελληνικά</source>
        <translation>Griego</translation>
    </message>
    <message>
        <location filename="language.h" line="55"/>
        <source>British English</source>
        <translation>Inglés Británico</translation>
    </message>
    <message>
        <location filename="language.h" line="56"/>
        <source>American English</source>
        <translation>Ingles Americano</translation>
    </message>
    <message>
        <location filename="language.h" line="57"/>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="language.h" line="58"/>
        <source>Eesti</source>
        <translation>Estonio</translation>
    </message>
    <message>
        <location filename="language.h" line="59"/>
        <source>Euskara</source>
        <translation>Vasco</translation>
    </message>
    <message>
        <location filename="language.h" line="60"/>
        <source>فارسی</source>
        <translation>Farsi</translation>
    </message>
    <message>
        <location filename="language.h" line="61"/>
        <source>Suomi</source>
        <translation>Finés</translation>
    </message>
    <message>
        <location filename="language.h" line="62"/>
        <source>Føroyskt</source>
        <translation>Feroés</translation>
    </message>
    <message>
        <location filename="language.h" line="63"/>
        <source>Français</source>
        <translation>Francés</translation>
    </message>
    <message>
        <location filename="language.h" line="64"/>
        <source>Frysk</source>
        <translation>Frisón</translation>
    </message>
    <message>
        <location filename="language.h" line="65"/>
        <source>Gaeilge</source>
        <translation>Irlandés</translation>
    </message>
    <message>
        <location filename="language.h" line="66"/>
        <source>Gàidhlig</source>
        <translation>Escocés</translation>
    </message>
    <message>
        <location filename="language.h" line="67"/>
        <source>Galego</source>
        <translation>Gallego</translation>
    </message>
    <message>
        <location filename="language.h" line="68"/>
        <source>ગુજરાતી </source>
        <translation>Guyaratí</translation>
    </message>
    <message>
        <location filename="language.h" line="69"/>
        <source>Gaelg</source>
        <translation>Gaélico</translation>
    </message>
    <message>
        <location filename="language.h" line="70"/>
        <source>هَوُسَ</source>
        <translation>Hausa</translation>
    </message>
    <message>
        <location filename="language.h" line="71"/>
        <source>עברית</source>
        <translation>Hebreo</translation>
    </message>
    <message>
        <location filename="language.h" line="72"/>
        <source>हिन्दी</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <location filename="language.h" line="73"/>
        <source>Chhattisgarhi</source>
        <translation>Chatisgarí</translation>
    </message>
    <message>
        <location filename="language.h" line="74"/>
        <source>Hrvatski</source>
        <translation>Croata</translation>
    </message>
    <message>
        <location filename="language.h" line="75"/>
        <source>Hornjoserbsce</source>
        <translation>Soraba</translation>
    </message>
    <message>
        <location filename="language.h" line="76"/>
        <source>Magyar</source>
        <translation>Húngaro</translation>
    </message>
    <message>
        <location filename="language.h" line="77"/>
        <source>Հայերեն</source>
        <translation>Armenio</translation>
    </message>
    <message>
        <location filename="language.h" line="78"/>
        <source>Indonesia</source>
        <translation>Indonesio</translation>
    </message>
    <message>
        <location filename="language.h" line="79"/>
        <source>Iñupiak</source>
        <translation>Iñupiaq</translation>
    </message>
    <message>
        <location filename="language.h" line="80"/>
        <source>Íslenska</source>
        <translation>Islandés</translation>
    </message>
    <message>
        <location filename="language.h" line="81"/>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="language.h" line="82"/>
        <source>ᐃᓄᒃᑎᑐᑦ</source>
        <translation>Esquimal</translation>
    </message>
    <message>
        <location filename="language.h" line="83"/>
        <source>日本語</source>
        <translation>Japonés</translation>
    </message>
    <message>
        <location filename="language.h" line="84"/>
        <source>ქართული</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <location filename="language.h" line="85"/>
        <source>Қазақша</source>
        <translation>kazajo</translation>
    </message>
    <message>
        <location filename="language.h" line="86"/>
        <source>Kalaallisut</source>
        <translation>Groenlandés</translation>
    </message>
    <message>
        <location filename="language.h" line="87"/>
        <source>ខ្មែរ</source>
        <translation>Jemer</translation>
    </message>
    <message>
        <location filename="language.h" line="88"/>
        <source>ಕನ್ನಡ</source>
        <translation>Canarés</translation>
    </message>
    <message>
        <location filename="language.h" line="89"/>
        <source>한국어</source>
        <translation>Coreano</translation>
    </message>
    <message>
        <location filename="language.h" line="90"/>
        <source>कश्मीरी - (كشميري)</source>
        <translation>Cachemir - (Cachemira)</translation>
    </message>
    <message>
        <location filename="language.h" line="91"/>
        <source>Kurdî</source>
        <translation>kurdo</translation>
    </message>
    <message>
        <location filename="language.h" line="92"/>
        <source>Kernewek</source>
        <translation>Córnico</translation>
    </message>
    <message>
        <location filename="language.h" line="93"/>
        <source>Кыргызча</source>
        <translation>kirguís</translation>
    </message>
    <message>
        <location filename="language.h" line="94"/>
        <source>Lëtzebuergesch</source>
        <translation>Luxemburgués</translation>
    </message>
    <message>
        <location filename="language.h" line="95"/>
        <source>Limburgs</source>
        <translation>Limburgués</translation>
    </message>
    <message>
        <location filename="language.h" line="96"/>
        <source>ລາວ</source>
        <translation>Lao</translation>
    </message>
    <message>
        <location filename="language.h" line="97"/>
        <source>Lietuvių</source>
        <translation>Lituano</translation>
    </message>
    <message>
        <location filename="language.h" line="98"/>
        <source>Latviešu</source>
        <translation>Letón</translation>
    </message>
    <message>
        <location filename="language.h" line="99"/>
        <source>Maithili</source>
        <translation>Maithili</translation>
    </message>
    <message>
        <location filename="language.h" line="100"/>
        <source>Malagasy</source>
        <translation>Malgache</translation>
    </message>
    <message>
        <location filename="language.h" line="101"/>
        <source>Ebon</source>
        <translation>Marshalés</translation>
    </message>
    <message>
        <location filename="language.h" line="102"/>
        <source>Māori</source>
        <translation>Maorí</translation>
    </message>
    <message>
        <location filename="language.h" line="103"/>
        <source>Македонски</source>
        <translation>Macedonio</translation>
    </message>
    <message>
        <location filename="language.h" line="104"/>
        <source>മലയാളം</source>
        <translation>Malabar</translation>
    </message>
    <message>
        <location filename="language.h" line="105"/>
        <source>Монгол</source>
        <translation>Mongol</translation>
    </message>
    <message>
        <location filename="language.h" line="106"/>
        <source>मराठी</source>
        <translation>Maratí</translation>
    </message>
    <message>
        <location filename="language.h" line="107"/>
        <source>Bahasa Melayu</source>
        <translation>Malayo</translation>
    </message>
    <message>
        <location filename="language.h" line="108"/>
        <source>Malti</source>
        <translation>Maltés</translation>
    </message>
    <message>
        <location filename="language.h" line="109"/>
        <source>Myanmasa</source>
        <translation>Birmano</translation>
    </message>
    <message>
        <location filename="language.h" line="110"/>
        <source>Ekakairũ Naoero</source>
        <translation>Nauruano</translation>
    </message>
    <message>
        <location filename="language.h" line="111"/>
        <source>Norsk (bokmål)</source>
        <translation>Noruego (Escrito)</translation>
    </message>
    <message>
        <location filename="language.h" line="112"/>
        <source>Plattdüütsch</source>
        <translation>Alemán bajo</translation>
    </message>
    <message>
        <location filename="language.h" line="113"/>
        <source>नेपाली</source>
        <translation>Nepalí</translation>
    </message>
    <message>
        <location filename="language.h" line="114"/>
        <source>Nederlands</source>
        <translation>Holandés</translation>
    </message>
    <message>
        <location filename="language.h" line="115"/>
        <source>Norsk (nynorsk)</source>
        <translation>Noruego (Moderno)</translation>
    </message>
    <message>
        <location filename="language.h" line="116"/>
        <source>IsiNdebele</source>
        <translation> Ndebele</translation>
    </message>
    <message>
        <location filename="language.h" line="117"/>
        <source>Sesotho sa Leboa</source>
        <translation>Sesotho sa leboa</translation>
    </message>
    <message>
        <location filename="language.h" line="118"/>
        <source>Occitan</source>
        <translation>Occitano</translation>
    </message>
    <message>
        <location filename="language.h" line="119"/>
        <source>Oromoo</source>
        <translation>Oromo</translation>
    </message>
    <message>
        <location filename="language.h" line="120"/>
        <source>ଓଡ଼ିଆ</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <location filename="language.h" line="121"/>
        <source>Иронау</source>
        <translation>Osetio</translation>
    </message>
    <message>
        <location filename="language.h" line="122"/>
        <source>ਪੰਜਾਬੀ</source>
        <translation>Panyabí</translation>
    </message>
    <message>
        <location filename="language.h" line="123"/>
        <source>Polski</source>
        <translation>Polaco</translation>
    </message>
    <message>
        <location filename="language.h" line="124"/>
        <source>پښتو</source>
        <translation>Pastún</translation>
    </message>
    <message>
        <location filename="language.h" line="125"/>
        <source>Português</source>
        <translation>Portugués</translation>
    </message>
    <message>
        <location filename="language.h" line="126"/>
        <source>Português do Brasil</source>
        <translation>Portugués de Brasil</translation>
    </message>
    <message>
        <location filename="language.h" line="127"/>
        <source>Română</source>
        <translation>Rumano</translation>
    </message>
    <message>
        <location filename="language.h" line="128"/>
        <source>Русский</source>
        <translation>Ruso</translation>
    </message>
    <message>
        <location filename="language.h" line="129"/>
        <source>Kinyarwanda</source>
        <translation>Kinyarwanda</translation>
    </message>
    <message>
        <location filename="language.h" line="130"/>
        <source>संस्कृत</source>
        <translation>Sánscrito</translation>
    </message>
    <message>
        <location filename="language.h" line="131"/>
        <source>Sardu</source>
        <translation>Sardo</translation>
    </message>
    <message>
        <location filename="language.h" line="132"/>
        <source>سنڌي</source>
        <translation>Sindhi</translation>
    </message>
    <message>
        <location filename="language.h" line="133"/>
        <source>Sámegiella</source>
        <translation>Sami septentrional</translation>
    </message>
    <message>
        <location filename="language.h" line="134"/>
        <source>සිංහල</source>
        <translation>Cingalés</translation>
    </message>
    <message>
        <location filename="language.h" line="135"/>
        <source>Slovenčina</source>
        <translation>Eslovaco</translation>
    </message>
    <message>
        <location filename="language.h" line="136"/>
        <source>Slovenščina</source>
        <translation>Esloveno</translation>
    </message>
    <message>
        <location filename="language.h" line="137"/>
        <source>Soomaaliga</source>
        <translation>Somalí</translation>
    </message>
    <message>
        <location filename="language.h" line="138"/>
        <source>Shqip</source>
        <translation>Albanés</translation>
    </message>
    <message>
        <location filename="language.h" line="139"/>
        <source>Српски</source>
        <translation>Serbio</translation>
    </message>
    <message>
        <location filename="language.h" line="140"/>
        <source>srpski (latinica)</source>
        <translation>Serbio (Latín)</translation>
    </message>
    <message>
        <location filename="language.h" line="141"/>
        <source>SiSwati</source>
        <translation>Suazi</translation>
    </message>
    <message>
        <location filename="language.h" line="142"/>
        <source>Sesotho</source>
        <translation>Sesoto</translation>
    </message>
    <message>
        <location filename="language.h" line="143"/>
        <source>Svenska</source>
        <translation>Sueco</translation>
    </message>
    <message>
        <location filename="language.h" line="144"/>
        <source>Swahili</source>
        <translation>Suajili</translation>
    </message>
    <message>
        <location filename="language.h" line="145"/>
        <source>தமிழ்</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <location filename="language.h" line="146"/>
        <source>తెలుగు</source>
        <translation>Telugú</translation>
    </message>
    <message>
        <location filename="language.h" line="147"/>
        <source>Тоҷикӣ</source>
        <translation>Tayiko</translation>
    </message>
    <message>
        <location filename="language.h" line="148"/>
        <source>ภาษาไทย</source>
        <translation>Tailandés</translation>
    </message>
    <message>
        <location filename="language.h" line="149"/>
        <source>ትግርኛ</source>
        <translation>Tigriña</translation>
    </message>
    <message>
        <location filename="language.h" line="150"/>
        <source>Türkmen</source>
        <translation>Turcomano</translation>
    </message>
    <message>
        <location filename="language.h" line="151"/>
        <source>Setswana</source>
        <translation>Setsuana</translation>
    </message>
    <message>
        <location filename="language.h" line="152"/>
        <source>Türkçe</source>
        <translation>Turco</translation>
    </message>
    <message>
        <location filename="language.h" line="153"/>
        <source>Xitsonga</source>
        <translation>Tsonga</translation>
    </message>
    <message>
        <location filename="language.h" line="154"/>
        <source>Татарский</source>
        <translation>Tártaro</translation>
    </message>
    <message>
        <location filename="language.h" line="155"/>
        <source>ئۇيغۇرچە</source>
        <translation>Uigur</translation>
    </message>
    <message>
        <location filename="language.h" line="156"/>
        <source>Українська</source>
        <translation>Ucraniano</translation>
    </message>
    <message>
        <location filename="language.h" line="157"/>
        <source>اردو</source>
        <translation>Urdu</translation>
    </message>
    <message>
        <location filename="language.h" line="158"/>
        <source>Oʻzbekcha</source>
        <translation>Uzbeko</translation>
    </message>
    <message>
        <location filename="language.h" line="159"/>
        <source>Uzbek (Cyrillic)</source>
        <translation>Uzbeko (Cirílico)</translation>
    </message>
    <message>
        <location filename="language.h" line="160"/>
        <source>Venda</source>
        <translation>Venda</translation>
    </message>
    <message>
        <location filename="language.h" line="161"/>
        <source>Tiếng Việt</source>
        <translation>Vietnamita</translation>
    </message>
    <message>
        <location filename="language.h" line="162"/>
        <source>Walon</source>
        <translation>Valón</translation>
    </message>
    <message>
        <location filename="language.h" line="163"/>
        <source>Wolof</source>
        <translation>Wólof</translation>
    </message>
    <message>
        <location filename="language.h" line="164"/>
        <source>isixhosa</source>
        <translation>Xhosa</translation>
    </message>
    <message>
        <location filename="language.h" line="165"/>
        <source>ייִדיש</source>
        <translation>Yidis</translation>
    </message>
    <message>
        <location filename="language.h" line="166"/>
        <source>Yorùbá</source>
        <translation>Yoruba</translation>
    </message>
    <message>
        <location filename="language.h" line="167"/>
        <source>简体中文</source>
        <translation>Chino simplificado</translation>
    </message>
    <message>
        <location filename="language.h" line="168"/>
        <source>繁體中文(香港)</source>
        <translation>Chino tradicional (Hong Kong)</translation>
    </message>
    <message>
        <location filename="language.h" line="169"/>
        <source>正體中文</source>
        <translation>Chino tradicional</translation>
    </message>
    <message>
        <location filename="language.h" line="170"/>
        <source>isiZulu</source>
        <translation>Zulú</translation>
    </message>
</context>
</TS>